@@ -31,8 +31,11 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
 
+import org.apache.commons.io.output.UnsynchronizedByteArrayOutputStream;
 import org.apache.poi.ss.SpreadsheetVersion;
 import org.apache.poi.ss.usermodel.Cell;
+import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.util.AreaReference;
 import org.apache.poi.ss.util.CellReference;
 import org.apache.poi.util.TempFile;
@@ -484,9 +487,6 @@ public final class TestXSSFTable {
         }
     }
 
-    /**
-     * See https://stackoverflow.com/questions/44407111/apache-poi-cant-format-filled-cells-as-numeric
-     */
     @Test
     void testNumericCellsInTable() throws IOException {
         try (XSSFWorkbook wb = new XSSFWorkbook()) {
@@ -592,6 +592,46 @@ public final class TestXSSFTable {
         }
     }
 
+    @Test
+    void testBug65669() throws IOException {
+        String[] testValues = new String[] {"C'olumn", "Column"};
+        for (String testValue : testValues) {
+            try (XSSFWorkbook wb = new XSSFWorkbook()) {
+                XSSFSheet sheet = wb.createSheet();
+
+                // Set the values for the table
+                for (int i = 0; i < 3; i++) {
+                    // Create row
+                    Row row = sheet.createRow(i);
+                    for (int j = 0; j < 3; j++) {
+                        // Create cell
+                        Cell cell = row.createCell(j);
+                        if (i == 0) {
+                            final String columnName = testValue + (j + 1);
+                            cell.setCellValue(columnName);
+                        } else {
+                            if (j != 2) {
+                                cell.setCellValue((i + 1.0) * (j + 1.0));
+                            }
+                        }
+                    }
+                }
+
+                // Create Table
+                AreaReference reference = wb.getCreationHelper().createAreaReference(
+                        new CellReference(0, 0), new CellReference(2, 2));
+                XSSFTable table = sheet.createTable(reference);
+                table.setName("Table1");
+                table.setDisplayName("Table1");
+                for (int i = 1; i < 3; i++) {
+                    Cell cell = sheet.getRow(i).getCell(2);
+                    assertNotNull(cell);
+                    cell.setCellFormula("Table1[[#This Row],[" + testValue + "1]]");
+                }
+            }
+        }
+    }
+
     private static XSSFTable addTable(XSSFSheet sheet,int nRow, int nCol, int nNumRows, int nNumCols) {
         for (int i = 0; i < nNumRows; i++) {
             XSSFRow row = sheet.createRow(i + nRow);
@@ -609,4 +649,58 @@ public final class TestXSSFTable {
         final AreaReference area = new AreaReference(upperLeft, lowerRight, SpreadsheetVersion.EXCEL2007);
         return sheet.createTable(area);
     }
+
+    @Test
+    void testNamesWithNewLines() throws IOException {
+        try (
+                XSSFWorkbook wb = new XSSFWorkbook();
+                UnsynchronizedByteArrayOutputStream bos = new UnsynchronizedByteArrayOutputStream()
+        ) {
+            XSSFSheet sheet = wb.createSheet();
+
+            // headers
+            XSSFRow headersRow = sheet.createRow(0);
+            headersRow.createCell(0).setCellValue("Column1");
+            headersRow.createCell(1).setCellValue("Column2");
+
+            // a second row
+            XSSFRow row = sheet.createRow(1);
+            row.createCell(0).setCellValue(1);
+            row.createCell(1).setCellValue(2);
+
+            // create a table
+            AreaReference area = wb.getCreationHelper().createAreaReference(
+                    new CellReference(sheet.getRow(0).getCell(0)),
+                    new CellReference(sheet.getRow(1).getCell(1))
+            );
+            XSSFTable table = sheet.createTable(area);
+
+            // styling (no problem here)
+            sheet.setColumnWidth(0, 5000);
+            sheet.setColumnWidth(1, 5000);
+            CTTable cttable = table.getCTTable();
+            cttable.addNewTableStyleInfo();
+            XSSFTableStyleInfo style = (XSSFTableStyleInfo) table.getStyle();
+            style.setName("TableStyleMedium6");
+            style.setShowColumnStripes(false);
+            style.setShowRowStripes(true);
+            cttable.addNewAutoFilter().setRef(area.formatAsString());
+            CellStyle cellStyle = wb.createCellStyle();
+            cellStyle.setWrapText(true);
+            headersRow.getCell(0).setCellStyle(cellStyle);
+            headersRow.getCell(0).setCellValue("Column1\nwith a line break");
+
+            wb.write(bos);
+
+            try (XSSFWorkbook wb2 = new XSSFWorkbook(bos.toInputStream())) {
+                XSSFSheet wb2Sheet = wb2.getSheetAt(0);
+                List<XSSFTable> tables = wb2Sheet.getTables();
+                assertEquals(1, tables.size());
+                XSSFTable wb2Table = tables.get(0);
+                List<XSSFTableColumn> tabColumns = wb2Table.getColumns();
+                assertEquals(2, tabColumns.size());
+                assertEquals("Column1_x000a_with a line break", tabColumns.get(0).getName());
+            }
+        }
+    }
 }
