@@ -33,7 +33,6 @@ import java.util.Iterator;
 import java.util.List;
 
 import org.apache.commons.io.output.UnsynchronizedByteArrayOutputStream;
-import org.apache.commons.math3.util.ArithmeticUtils;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 import org.apache.poi.EmptyFileException;
@@ -64,6 +63,8 @@ public class POIFSFileSystem extends BlockStore
     private static final int DEFAULT_MAX_RECORD_LENGTH = 100_000;
     private static int MAX_RECORD_LENGTH = DEFAULT_MAX_RECORD_LENGTH;
 
+    private static final int MAX_ALLOCATION_SIZE = 250_000_000;
+
     private static final Logger LOG = LogManager.getLogger(POIFSFileSystem.class);
 
     /**
@@ -125,7 +126,7 @@ public class POIFSFileSystem extends BlockStore
     protected void createNewDataSource() {
         // Data needs to initially hold just the header block,
         //  a single bat block, and an empty properties section
-        long blockSize = ArithmeticUtils.mulAndCheck(bigBlockSize.getBigBlockSize(), 3L);
+        long blockSize = Math.multiplyExact(bigBlockSize.getBigBlockSize(), 3L);
         _data = new ByteArrayBackedDataSource(IOUtils.safelyAllocate(blockSize, MAX_RECORD_LENGTH));
     }
 
@@ -194,7 +195,7 @@ public class POIFSFileSystem extends BlockStore
      *
      * @param channel the FileChannel from which to read the data
      * @throws IOException on errors reading, or on invalid data
-     * @see POIFSFileSystem(FileChannel, boolean, boolean) this constructor gives more control over whether to
+     * @see #POIFSFileSystem(FileChannel, boolean, boolean) this constructor gives more control over whether to
      * close the provided channel
      */
     public POIFSFileSystem(FileChannel channel)
@@ -214,7 +215,7 @@ public class POIFSFileSystem extends BlockStore
      * @param channel  the FileChannel from which to read or read/write the data
      * @param readOnly whether the POIFileSystem will only be used in read-only mode
      * @throws IOException on errors reading, or on invalid data
-     * @see POIFSFileSystem(FileChannel, boolean, boolean) this constructor gives more control over whether to
+     * @see #POIFSFileSystem(FileChannel, boolean, boolean) this constructor gives more control over whether to
      * close the provided channel
      */
     public POIFSFileSystem(FileChannel channel, boolean readOnly)
@@ -334,6 +335,10 @@ public class POIFSFileSystem extends BlockStore
             if (maxSize > Integer.MAX_VALUE) {
                 throw new IllegalArgumentException("Unable read a >2gb file via an InputStream");
             }
+
+            // don't allow huge allocations with invalid header-values
+            IOUtils.safelyAllocateCheck(maxSize, MAX_ALLOCATION_SIZE);
+
             ByteBuffer data = ByteBuffer.allocate((int) maxSize);
 
             // Copy in the header
@@ -449,7 +454,7 @@ public class POIFSFileSystem extends BlockStore
         // Ensure there's a spot in the file for it
         ByteBuffer buffer = ByteBuffer.allocate(bigBlockSize.getBigBlockSize());
         // Header isn't in BATs
-        long writeTo = ArithmeticUtils.mulAndCheck(1L + offset, bigBlockSize.getBigBlockSize());
+        long writeTo = Math.multiplyExact(1L + offset, (long)bigBlockSize.getBigBlockSize());
         _data.write(buffer, writeTo);
         // All done
         return newBAT;
@@ -577,7 +582,7 @@ public class POIFSFileSystem extends BlockStore
                 offset++;
 
                 // Chain it
-                if (_xbat_blocks.size() == 0) {
+                if (_xbat_blocks.isEmpty()) {
                     _header.setXBATStart(offset);
                 } else {
                     _xbat_blocks.get(_xbat_blocks.size() - 1).setValueAt(
